@@ -13,6 +13,7 @@ use Test::Builder;
 	file_min_size_ok file_readable_ok file_not_readable_ok file_writeable_ok
 	file_not_writeable_ok file_executable_ok file_not_executable_ok
 	file_mode_is file_mode_isnt
+	file_mode_has file_mode_hasnt
 	file_is_symlink_ok
 	symlink_target_exists_ok symlink_target_is
 	symlink_target_dangles_ok
@@ -27,7 +28,7 @@ use Test::Builder;
 	file_mtime_gt_ok file_mtime_lt_ok file_mtime_age_ok
 	);
 
-$VERSION = '1.41';
+$VERSION = '1.44';
 
 {
 use warnings;
@@ -35,13 +36,15 @@ use warnings;
 
 my $Test = Test::Builder->new();
 
+=encoding utf8
+
 =head1 NAME
 
 Test::File -- test file attributes
 
 =head1 SYNOPSIS
 
-use Test::File;
+  use Test::File;
 
 =head1 DESCRIPTION
 
@@ -56,10 +59,13 @@ matter the permissions.
 Some attributes don't make sense outside of Unix, either, so some
 tests automatically skip if they think they won't work on the
 platform.  If you have a way to make these functions work on Windows,
-for instance, please send me a patch. :)
+for instance, please send me a patch. :) IF you want to pretend to be
+Windows on a non-Windows machine (for instance, to test C<skip()>),
+you can set the C<PRETEND_TO_BE_WINDOWS> environment variable.
 
-The optional NAME parameter for every function allows you to specify a name for the test.  If not
-supplied, a reasonable default will be generated.
+The optional NAME parameter for every function allows you to specify a
+name for the test.  If not supplied, a reasonable default will be
+generated.
 
 =head2 Functions
 
@@ -78,6 +84,7 @@ sub _normalize
 sub _win32
 	{
 	return 0 if $^O eq 'darwin';
+	return $ENV{PRETEND_TO_BE_WIN32} if defined $ENV{PRETEND_TO_BE_WIN32};
 	return $^O =~ m/Win/;
 	}
 
@@ -927,6 +934,90 @@ sub file_mode_isnt
 		}
 	}
 
+=item file_mode_has( FILENAME, MODE [, NAME ] )
+
+Ok if the file exists and has all the bits in mode turned on, not ok
+if the file does not exist or the mode does not match.  That is,
+C<< FILEMODE & MODE == MODE >> must be true.
+
+This test automatically skips if it thinks it is on a
+Windows platform.
+
+Contributed by Ricardo Signes C<< <rjbs@cpan.org> >>
+
+=cut
+
+sub file_mode_has
+	{
+	if( _win32() )
+		{
+		$Test->skip( "file_mode_has doesn't work on Windows!" );
+		return;
+		}
+
+	my $filename = _normalize( shift );
+	my $mode     = shift;
+
+	my $name     = shift || sprintf("%s mode has all bits of %04o", $filename, $mode);
+
+	my $present = -e $filename;
+	my $gotmode = $present ? (stat($filename))[2] : undef;
+	my $ok      = $present && ($gotmode & $mode) == $mode;
+
+	if( $ok )
+		{
+		$Test->ok(1, $name);
+		}
+	else
+		{
+		my $missing = ($gotmode ^ $mode) & $mode;
+		$Test->diag(sprintf("File [%s] mode is missing component %04o!", $filename, $missing) );
+		$Test->ok(0, $name);
+		}
+	}
+
+=item file_mode_hasnt( FILENAME, MODE [, NAME ] )
+
+Ok if the file exists and has all the bits in mode turned off, not ok
+if the file does not exist or the mode does not match.  That is,
+C<< FILEMODE & MODE == 0 >> must be true.
+
+This test automatically skips if it thinks it is on a
+Windows platform.
+
+Contributed by Ricardo Signes C<< <rjbs@cpan.org> >>
+
+=cut
+
+sub file_mode_hasnt
+	{
+	if( _win32() )
+		{
+		$Test->skip( "file_mode_hasnt doesn't work on Windows!" );
+		return;
+		}
+
+	my $filename = _normalize( shift );
+	my $mode     = shift;
+
+	my $name     = shift || sprintf("%s mode has no bits of %04o", $filename, $mode);
+
+	my $present = -e $filename;
+	my $gotmode = $present ? (stat($filename))[2] : undef;
+	my $ok      = $present && ($gotmode & $mode) == 0;
+
+	if( $ok )
+		{
+		$Test->ok(1, $name);
+		}
+	else
+		{
+		my $bad = $gotmode & $mode;
+		$Test->diag(sprintf("File [%s] mode has forbidden component %04o!", $filename, $bad) );
+		$Test->ok(0, $name);
+		}
+	}
+
 =item file_is_symlink_ok( FILENAME [, NAME ] )
 
 Ok if FILENAME is a symlink, even if it points to a non-existent
@@ -1686,7 +1777,7 @@ stuff.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2014 brian d foy.  All rights reserved.
+Copyright © 2002-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
